from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_NXP_ColdFire = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'MCF5212CAE66', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCF5212CAE66'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'MCU', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MCF5213EC.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_ColdFire.kicad_sym\nMCF5212CAE66\n\nMCU', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='QSPI_DIN/EZPD/CANRX/RXD1/PQS1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='QSPI_DOUT/EZPQ/CANTX/RXD0/PQS0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='QSPI_CLK/EZPCK/SCL/RTS1/PQS2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='QSPI_CS0/SDA/CTS1/PQS3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RCON/EZPCS',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='JTAG_EN',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='DTIN2/DTOUT2/PWM4/PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='DTIN3/DTOUT3/PWM6/PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='~{URTS1}/SYNCB/UTXD2/PUB2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='DTIN0/DTOUT0/PWM0/PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='DTIN1/DTOUT1/PWM2/PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='CLKMOD0',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='AN0/PAN0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='AN1/PAN1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AN2/PAN2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='AN3/PAN3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VSSA',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='VRL',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='VRH',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VCCA',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='AN7/PAN7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='AN6/PAN6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='AN5/PAN5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='AN4/PAN4',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VSTBY',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~{UCTS0}/CANRTX/PUA3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='GPT0/PWM1/PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='GPT1/PWM3/PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='GPT2PWM5//PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='GPT3/PWM7/PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='TCLK/PSTCLK/CLKOUT',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='GNDPLL',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='XTAL',func=pin_types.OUTPUT,unit=1),
            Pin(num='47',name='CLKIN/EXTAL',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='VCCPLL',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='~{BKPT}/TMS',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='URXD0/PUA1',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='DSI/TDI',func=pin_types.INPUT,unit=1),
            Pin(num='51',name='DSO/TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='54',name='DSCLK/~{TRST}',func=pin_types.INPUT,unit=1),
            Pin(num='55',name='ALLPST',func=pin_types.OUTPUT,unit=1),
            Pin(num='56',name='~{IRQ1}/PNQ1/SYNCA/PWM1',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='IRQ4*/PNQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='IRQ7*/PNQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='RSTI',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='UTXD0/PUA0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='RSTO',func=pin_types.OUTPUT,unit=1),
            Pin(num='61',name='~{UCTS1}/SYNCA/URXD2/PUB3',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='UTXD1/PUB0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='URXD1/PUB1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='~{URTS0}/CANTX/PUA2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SCL/PAS0/UTxD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SDA/PAS1/URxD2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCF5213-LQFP100', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCF5213-LQFP100'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'COLDFIRE', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_ColdFire.kicad_sym\nMCF5213-LQFP100\n\nCOLDFIRE', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='SCL/CANTX/PAS0/UTXD2',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='URXD1/PUB1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SDA/CANRX/PAS1/URXD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='QSPI_CS3/SYNCA/SYNCB/PQS6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='QSPI_CS2/PQS5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='QSPI_DIN/EZPD/CANRX/RXD1/PQS1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='QSPI_DOUT/EZPQ/CANTX/RXD0/PQS0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='QSPI_CLK/EZPCK/SCL/RTS1/PQS2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='QSPI_CS1/PQS4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='QSPI_CS0/SDA/CTS1/PQS3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RCON/EZPCS',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='JTAG_EN',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='~{UCTS2}/PUC3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='URXD2/PUC1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='UTXD2/PUC0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='~{URTS2}/PUC2',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='DTIN2/DTOUT2/PWM4/PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='DTIN3/DTOUT3/PWM6/PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PWM3/PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='DTIN0/DTOUT0/PWM0/PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='DTIN1/DTOUT1/PWM2/PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PWM1/PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='CLKMOD1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{URTS1}/SYNCB/UTXD2/PUB2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='CLKMOD0',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='AN0/PAN0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='AN1/PAN1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='AN2/PAN2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='AN3/PAN3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSSA',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='VRL',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VRH',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='50',name='VCCA',func=pin_types.INPUT,unit=1),
            Pin(num='51',name='AN7/PAN7',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='AN6/PAN6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='AN5/PAN5',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='AN4/PAN4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSTBY',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='GPT0/PWM1/PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='GPT1/PWM3/PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='~{UCTS0}/CANRX/PUA3',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PWM5/PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='GPT2PWM5//PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='GPT3/PWM7/PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PWM7/PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='TCLK/PSTCLK/CLKOUT',func=pin_types.INPUT,unit=1),
            Pin(num='65',name='PST0/PDD0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PST1/PDD1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='68',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='69',name='PST2/PDD2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='URXD0/PUA1',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PST3/PDD3',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='GNDPLL',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='XTAL',func=pin_types.OUTPUT,unit=1),
            Pin(num='73',name='CLKIN/EXTAL',func=pin_types.INPUT,unit=1),
            Pin(num='74',name='VCCPLL',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='~{BKPT}/TMS',func=pin_types.INPUT,unit=1),
            Pin(num='77',name='DDATA0/PDD4',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='DDATA1/PDD5',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='DSI/TDI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='UTXD0/PUA0',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='DSO/TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='81',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='82',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='DDATA2/PDD6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='DDATA3/PDD7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='DSCLK/~{TRST}',func=pin_types.INPUT,unit=1),
            Pin(num='86',name='ALLPST',func=pin_types.OUTPUT,unit=1),
            Pin(num='87',name='~{IRQ1}/PNQ1/SYNCA/PWM1',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='~{IRQ2}/PNQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='~{IRQ3}/PNQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{URTS0}/CANTX/PUA2',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='~{IRQ4}/PNQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='~{IRQ5}/PNQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='93',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='94',name='~{IRQ6}/PNQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='~{IRQ7}/PNQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='RSTI',func=pin_types.INPUT,unit=1),
            Pin(num='97',name='RSTO',func=pin_types.OUTPUT,unit=1),
            Pin(num='98',name='~{UCTS1}/SYNCA/URXD2/PUB3',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='UTXD1/PUB0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCF5282', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCF5282'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'COLDFIRE', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_ColdFire.kicad_sym\nMCF5282\n\nCOLDFIRE', 'pins':[
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='ERXCLK/PEH3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='ECRS/PEH0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='VDDF',func=pin_types.PWRIN,unit=1),
            Pin(num='A13',name='DDATA1/PDD5',func=pin_types.OUTPUT,unit=1),
            Pin(num='A14',name='PST2/PDD2',func=pin_types.OUTPUT,unit=1),
            Pin(num='A15',name='PST0/PDD0',func=pin_types.OUTPUT,unit=1),
            Pin(num='A16',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='A15/PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='A16/PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='A18/PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='A21/PF5/~{CS4}',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VPP',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='ETXD3/PEL7',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='ETXCLK/PEH7',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='ERXD3/PEL3',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='A14/PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='EMDC/PAS4/UTXD2',func=pin_types.INPUT,unit=1),
            Pin(num='B11',name='ECOL/PEH4',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='GNDF',func=pin_types.PWRIN,unit=1),
            Pin(num='B13',name='DDATA0/PDD4',func=pin_types.OUTPUT,unit=1),
            Pin(num='B14',name='PST1/PDD1',func=pin_types.OUTPUT,unit=1),
            Pin(num='B15',name='~{IRQ7}/PNQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='~{IRQ6}/PNQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='A13/PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='A17/PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='A19/PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='GNDF',func=pin_types.PASSIVE,unit=1),
            Pin(num='B6',name='A22/PF6/~{CS5}',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='ETXD2/PEL6',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='ERXER/PEL0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='ERXD2/PEL2',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='A12/PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='EMDIO/PAS5/URXD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='DDATA3/PDD7',func=pin_types.OUTPUT,unit=1),
            Pin(num='C13',name='PST3/PDD3',func=pin_types.OUTPUT,unit=1),
            Pin(num='C14',name='~{IRQ5}/PNQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='~{IRQ4}/PNQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='~{IRQ3}/PNQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='A11/PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='A10/PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='A20/PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDDF',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='A23/PF7/~{CS6}',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='ETXD1/PEL5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='ERXDV/PEH2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='ERXD1/PEL1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='A9/PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='ETXER/PEL4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='VDDF',func=pin_types.PWRIN,unit=1),
            Pin(num='D12',name='DDATA2/PDD6',func=pin_types.OUTPUT,unit=1),
            Pin(num='D14',name='~{IRQ2}/PNQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='~{IRQ1}/PNQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='CANRX/PAS3/URxD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='A8/PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='A7/PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='A6/PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VDDF',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='ETXEN/PEH6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='ETXD0/PEH5',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='ERXDO/PEH1',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='A5/PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='E12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='CANTX/PAS2/UTxD2',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='SDA/PAS1/URxD2',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='SCL/PAS0/UTxD2',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='QSPI_DIN/PQS1',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='A4/PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='A3/PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='A2/PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='A1/PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='QSPI_DOUT/PQS0',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='QSPI_CLK/PQS2',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='QSPI_CS0/PQS3',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='QSPI_CS1/PQS4',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='A0/PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='D31/PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='D30/PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='QSPI_CS2/PQS5',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='QSPI_CS3/PQS6',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='~{DRAMW}/PSD3',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='~{SDRAM_CS0}/PSD1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='D29/PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='D28/PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='D27/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='D26/PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H11',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='~{SDRAM_CS1}/PSD2',func=pin_types.OUTPUT,unit=1),
            Pin(num='H14',name='SCKE/PSD0',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='~{SRAS}/PSD5',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='~{SCAS}/PSD4',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='D25/PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='D24/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='D23/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='D22/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='DTOUT0/PTD0/~{UCTS1}/~{UCTS0}',func=pin_types.INPUT,unit=1),
            Pin(num='J14',name='DTIN0/PTD1/~{UCTS1}/~{UCTS0}',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='DTOUT1/PTD2/~{URTS1}/~{URTS0}',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='DTIN1/PTD3/~{URTS1}/~{URTS0}',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='D21/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='D20/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='D19/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='J7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='J8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='D18/PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='DTOUT2/PTC0/~{UCTS1}/~{UCTS0}',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='DTIN2/PTC1/~{UCTS1}/~{UCTS0}',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='DTOUT3/PTC2/~{URTS1}/~{URTS0}',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='DTIN3/PTC3/~{URTS1}/~{URTS0}',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='D17/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='D16/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='K8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='D15/PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='L12',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='~{CS0}/PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='~{CS1}/PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='~{CS2}/PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='~{CS3}/PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='D14/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='D13/PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='D12/PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='D11/PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='M14',name='~{TIP}/PE0/SYNCB',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='~{TS}/PE1/SYNCA',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='SIZ0/PE2/SYNCB',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='D10/PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='D9/PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='D8/PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='M6',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='M8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='M9',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='D7/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='N11',name='VSTBY',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='GPTB0/PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='GPTA0/PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='SIZ1/PE3/SYNCA',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='R/W/PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='~{OE}/PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='D6/PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='D5/PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='D3/PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='URXD0/PUA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='N8',name='VCCPLL',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='D4/PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='~{BKPT}/TMS',func=pin_types.INPUT,unit=1),
            Pin(num='P11',name='RSTO',func=pin_types.OUTPUT,unit=1),
            Pin(num='P12',name='GPTB1/PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='GPTA1/PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='~{BS3}/PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='~{TEA}/PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='~{TA}/PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='VDDH',func=pin_types.PWRIN,unit=1),
            Pin(num='P3',name='AN55/PQA3/ETRIG1',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='VRH',func=pin_types.INPUT,unit=1),
            Pin(num='P5',name='VSSA',func=pin_types.INPUT,unit=1),
            Pin(num='P6',name='D0/PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='UTXD1/PUA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='GNDPLL',func=pin_types.PASSIVE,unit=1),
            Pin(num='P9',name='DSCLK/~{TRST}',func=pin_types.INPUT,unit=1),
            Pin(num='R1',name='AN3/PQB3/ANZ',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='DSI/TDI',func=pin_types.INPUT,unit=1),
            Pin(num='R11',name='RSTI',func=pin_types.INPUT,unit=1),
            Pin(num='R12',name='GPTB2/PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='GPTA2/PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='CLKMOD0',func=pin_types.INPUT,unit=1),
            Pin(num='R15',name='~{BS1}/PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='~{BS0}/PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='AN1/PQB1/ANX',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='AN56/PQA4/ETRIG2',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='AN52/PQA0/MA0',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='VCCA',func=pin_types.INPUT,unit=1),
            Pin(num='R6',name='D1/PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='URXD1/PUA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='XTAL',func=pin_types.OUTPUT,unit=1),
            Pin(num='R9',name='JTAG_EN',func=pin_types.INPUT,unit=1),
            Pin(num='T1',name='VSSA',func=pin_types.INPUT,unit=1),
            Pin(num='T10',name='DSO/TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='T11',name='RCON',func=pin_types.INPUT,unit=1),
            Pin(num='T12',name='GPTB3/PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='GPTA3/PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='CLKMOD1',func=pin_types.INPUT,unit=1),
            Pin(num='T15',name='~{BS2}/PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='T2',name='AN2/PQB2/ANY',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='AN0/PQB0/ANW',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='AN53/PQA1/MA1',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='VRL',func=pin_types.INPUT,unit=1),
            Pin(num='T6',name='D2/PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='UTXD0/PUA0',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='CLKIN/EXTAL',func=pin_types.INPUT,unit=1),
            Pin(num='T9',name='TCLK',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCF5328-BGA256', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCF5328-BGA256'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_ColdFire.kicad_sym\nMCF5328-BGA256\n\n', 'pins':[
            Pin(num='A10',name='LCD_LSCLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='A11',name='LCD_PS',func=pin_types.OUTPUT,unit=1),
            Pin(num='A12',name='FB_CS3',func=pin_types.OUTPUT,unit=1),
            Pin(num='A13',name='FB_CS4',func=pin_types.OUTPUT,unit=1),
            Pin(num='A14',name='A20',func=pin_types.OUTPUT,unit=1),
            Pin(num='A15',name='A17',func=pin_types.OUTPUT,unit=1),
            Pin(num='A16',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='A2',name='FEC_TXCLK',func=pin_types.INPUT,unit=1),
            Pin(num='A3',name='LCD_D4/FEC_TXER',func=pin_types.OUTPUT,unit=1),
            Pin(num='A4',name='LCD_D5/FEC_TXEN',func=pin_types.OUTPUT,unit=1),
            Pin(num='A5',name='LCD_D9/FEC_RXD1',func=pin_types.OUTPUT,unit=1),
            Pin(num='A6',name='FEC_RXD2/ULPI_DATA6',func=pin_types.INPUT,unit=1),
            Pin(num='A7',name='LCD_D15/FEC_COL',func=pin_types.OUTPUT,unit=1),
            Pin(num='A8',name='FEC_COL/ULPI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='A9',name='LCD_CLS',func=pin_types.OUTPUT,unit=1),
            Pin(num='B1',name='FEC_TXER',func=pin_types.OUTPUT,unit=1),
            Pin(num='B10',name='LCD_LP/LCD_HSYNC',func=pin_types.OUTPUT,unit=1),
            Pin(num='B11',name='LCD_REV',func=pin_types.OUTPUT,unit=1),
            Pin(num='B12',name='FB_CS2',func=pin_types.OUTPUT,unit=1),
            Pin(num='B13',name='FB_CS5',func=pin_types.OUTPUT,unit=1),
            Pin(num='B14',name='A19',func=pin_types.OUTPUT,unit=1),
            Pin(num='B15',name='A16',func=pin_types.OUTPUT,unit=1),
            Pin(num='B16',name='A14/SD_BA0',func=pin_types.OUTPUT,unit=1),
            Pin(num='B2',name='FEC_TXEN',func=pin_types.OUTPUT,unit=1),
            Pin(num='B3',name='LCD_D1/FEC_TXD1',func=pin_types.OUTPUT,unit=1),
            Pin(num='B4',name='LCD_D3/FEC_TXD3',func=pin_types.OUTPUT,unit=1),
            Pin(num='B5',name='LCD_D8/FEC_RXD0',func=pin_types.OUTPUT,unit=1),
            Pin(num='B6',name='FEC_RXD1/ULPI_DATA5',func=pin_types.INPUT,unit=1),
            Pin(num='B7',name='LCD_D14/FEC_CRS',func=pin_types.OUTPUT,unit=1),
            Pin(num='B8',name='FEC_CRS/ULPI_DIR',func=pin_types.INPUT,unit=1),
            Pin(num='B9',name='LCD_ACD/LCD_OE',func=pin_types.OUTPUT,unit=1),
            Pin(num='C1',name='FEC_MDC/I2C_SCL',func=pin_types.OUTPUT,unit=1),
            Pin(num='C10',name='LCD_FLM/LCD_VSYNC',func=pin_types.OUTPUT,unit=1),
            Pin(num='C11',name='LCD_SPL_SPR',func=pin_types.OUTPUT,unit=1),
            Pin(num='C12',name='FB_CS1',func=pin_types.OUTPUT,unit=1),
            Pin(num='C13',name='A23/FB_CS5',func=pin_types.OUTPUT,unit=1),
            Pin(num='C14',name='A18',func=pin_types.OUTPUT,unit=1),
            Pin(num='C15',name='A13/SD_A13',func=pin_types.OUTPUT,unit=1),
            Pin(num='C16',name='A12/SD_A12',func=pin_types.OUTPUT,unit=1),
            Pin(num='C2',name='FEC_MDIO/I2C_SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='LCD_D0/FEC_TXD0',func=pin_types.OUTPUT,unit=1),
            Pin(num='C4',name='LCD_D2/FEC_TXD2',func=pin_types.OUTPUT,unit=1),
            Pin(num='C5',name='LCD_D7/FEC_RXER',func=pin_types.OUTPUT,unit=1),
            Pin(num='C6',name='FEC_RXD0/ULPI_DATA4',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='LCD_D13/FEC_RXCLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='C8',name='FEC_RXCLK/ULPI_NXT',func=pin_types.INPUT,unit=1),
            Pin(num='C9',name='LCD_D17',func=pin_types.OUTPUT,unit=1),
            Pin(num='D1',name='FEC_TXD1/ULPI_DATA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='D10',name='LCD_CONTRAST',func=pin_types.OUTPUT,unit=1),
            Pin(num='D11',name='/U1CTS/SSI_BCLK',func=pin_types.INPUT,unit=1),
            Pin(num='D12',name='FB_CS0',func=pin_types.OUTPUT,unit=1),
            Pin(num='D13',name='A22/FB_CS4',func=pin_types.OUTPUT,unit=1),
            Pin(num='D14',name='A15/SD_BA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='D15',name='A11/SD-A11',func=pin_types.OUTPUT,unit=1),
            Pin(num='D16',name='A10',func=pin_types.OUTPUT,unit=1),
            Pin(num='D2',name='FEC_TXD2/ULPI_DATA2',func=pin_types.OUTPUT,unit=1),
            Pin(num='D3',name='FEC_TDX3/ULPI_DATA3',func=pin_types.OUTPUT,unit=1),
            Pin(num='D4',name='FEC_RXER',func=pin_types.INPUT,unit=1),
            Pin(num='D5',name='LCD_D6/FEC_TXCLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='D6',name='LCD_D11/FEC_RXD3',func=pin_types.OUTPUT,unit=1),
            Pin(num='D7',name='LCD_D12/FEC_RXDV',func=pin_types.OUTPUT,unit=1),
            Pin(num='D8',name='FEC_RXDV/ULPI_STP',func=pin_types.INPUT,unit=1),
            Pin(num='D9',name='LCD_D16',func=pin_types.OUTPUT,unit=1),
            Pin(num='E1',name='DT2IN/DT2OUT',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='/U1RTS/SSI_FS',func=pin_types.OUTPUT,unit=1),
            Pin(num='E11',name='U1TXD/SSI_TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='E12',name='U1RXD/SSI_RXD',func=pin_types.INPUT,unit=1),
            Pin(num='E13',name='A21',func=pin_types.OUTPUT,unit=1),
            Pin(num='E14',name='A9/SD_A9',func=pin_types.OUTPUT,unit=1),
            Pin(num='E15',name='A8/SD_A8',func=pin_types.OUTPUT,unit=1),
            Pin(num='E16',name='A7/SD_A7',func=pin_types.OUTPUT,unit=1),
            Pin(num='E2',name='DT1IN/DT1OUT',func=pin_types.INPUT,unit=1),
            Pin(num='E3',name='DT0IN/TD0OUT',func=pin_types.INPUT,unit=1),
            Pin(num='E4',name='FEC_TXD0/ULPI_DATA0',func=pin_types.OUTPUT,unit=1),
            Pin(num='E5',name='IVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='LCD_D10/FEC_RXD2',func=pin_types.OUTPUT,unit=1),
            Pin(num='E7',name='FEC_RXD3/ULPI_DATA7',func=pin_types.INPUT,unit=1),
            Pin(num='E8',name='EVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='SD_VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='DT3IN/DT3OUT',func=pin_types.INPUT,unit=1),
            Pin(num='F10',name='SD_VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='SD_VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='A6/SD_A6',func=pin_types.OUTPUT,unit=1),
            Pin(num='F14',name='A5/SD_A5',func=pin_types.OUTPUT,unit=1),
            Pin(num='F15',name='A4/SD_A4',func=pin_types.OUTPUT,unit=1),
            Pin(num='F16',name='A3/SD_A3',func=pin_types.OUTPUT,unit=1),
            Pin(num='F2',name='I2C_SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='I2C_SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='SSI_BCLK/U2CTS',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='EVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='EVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='EVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='EVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='SD_VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='SSI_TXD/U2TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='SD_VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='IVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='TA',func=pin_types.INPUT,unit=1),
            Pin(num='G14',name='A0/SD_A0',func=pin_types.OUTPUT,unit=1),
            Pin(num='G15',name='A1/SD_A1',func=pin_types.OUTPUT,unit=1),
            Pin(num='G16',name='A2/SD_A2',func=pin_types.OUTPUT,unit=1),
            Pin(num='G2',name='SSI_RXD/U2RXD',func=pin_types.INPUT,unit=1),
            Pin(num='G3',name='SSI_FS/U2RTS',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='SSI_MCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='EVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='EVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='/SD_CS0',func=pin_types.OUTPUT,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='H11',name='SD_VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='DRAMSEL',func=pin_types.INPUT,unit=1),
            Pin(num='H13',name='PWM7',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PWM5',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PWM3/DT3OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='PWM1/DT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='SD_CKE',func=pin_types.OUTPUT,unit=1),
            Pin(num='H3',name='/SD_WE',func=pin_types.OUTPUT,unit=1),
            Pin(num='H4',name='TS/DACK0',func=pin_types.OUTPUT,unit=1),
            Pin(num='H5',name='EVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='EVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='D13/FB_D29',func=pin_types.OUTPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='EVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PLL_VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='/IRQ7',func=pin_types.INPUT,unit=1),
            Pin(num='J14',name='/IRQ6/VBUS_EN',func=pin_types.INPUT,unit=1),
            Pin(num='J15',name='/IRQ5/VBUS_OC',func=pin_types.INPUT,unit=1),
            Pin(num='J16',name='/IRQ4/SSI_MCLK',func=pin_types.INPUT,unit=1),
            Pin(num='J2',name='D14/FB_D30',func=pin_types.OUTPUT,unit=1),
            Pin(num='J3',name='D15/FB_D31',func=pin_types.OUTPUT,unit=1),
            Pin(num='J4',name='/SD_CS1',func=pin_types.OUTPUT,unit=1),
            Pin(num='J5',name='SD_VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='SD_VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='D9/FB_D25',func=pin_types.OUTPUT,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='EVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='EVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='PLL_VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='K14',name='/IRQ3',func=pin_types.INPUT,unit=1),
            Pin(num='K15',name='/IRQ2/USB_CLKIN',func=pin_types.INPUT,unit=1),
            Pin(num='K16',name='/IRQ1/DREQ1',func=pin_types.INPUT,unit=1),
            Pin(num='K2',name='D10/FB_D26',func=pin_types.OUTPUT,unit=1),
            Pin(num='K3',name='D11/FB_D27',func=pin_types.OUTPUT,unit=1),
            Pin(num='K4',name='D12/FB_D28',func=pin_types.OUTPUT,unit=1),
            Pin(num='K5',name='SD_VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='SD_VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='SD_DQS3',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='EVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='EVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='L14',name='USBOTG_VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L15',name='USBOTG_M',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='USBOTG_P',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='D8/FB_D24',func=pin_types.OUTPUT,unit=1),
            Pin(num='L3',name='BE/BWE1/SD_DQM1',func=pin_types.OUTPUT,unit=1),
            Pin(num='L4',name='BE/BWE3/SD_DQM3',func=pin_types.OUTPUT,unit=1),
            Pin(num='L5',name='SD_VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='SD_VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='SD_VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='SD_VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='EVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='D31/SD_D31',func=pin_types.OUTPUT,unit=1),
            Pin(num='M10',name='EVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='IVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='IVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='JTAG_EN',func=pin_types.INPUT,unit=1),
            Pin(num='M14',name='USBHOST_VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='M15',name='USBHOST_M',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='USBHOST_P',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='D30/SD_D30',func=pin_types.OUTPUT,unit=1),
            Pin(num='M3',name='D29/SD_D29',func=pin_types.OUTPUT,unit=1),
            Pin(num='M4',name='D28/SD_D28',func=pin_types.OUTPUT,unit=1),
            Pin(num='M5',name='IVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M6',name='SD_VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='SD_VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M8',name='/RCON',func=pin_types.INPUT,unit=1),
            Pin(num='M9',name='EVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='D27/SD_D27',func=pin_types.OUTPUT,unit=1),
            Pin(num='N10',name='DDATA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='N11',name='DSO/TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='N12',name='QSPI_DIN/U2CTS',func=pin_types.INPUT,unit=1),
            Pin(num='N13',name='PLL_TEST',func=pin_types.INPUT,unit=1),
            Pin(num='N14',name='DSI/TDI',func=pin_types.INPUT,unit=1),
            Pin(num='N15',name='/RESET',func=pin_types.INPUT,unit=1),
            Pin(num='N16',name='XTAL',func=pin_types.OUTPUT,unit=1),
            Pin(num='N2',name='D26/SD_D26',func=pin_types.OUTPUT,unit=1),
            Pin(num='N3',name='D25/SD_D25',func=pin_types.OUTPUT,unit=1),
            Pin(num='N4',name='D24/SD_D24',func=pin_types.OUTPUT,unit=1),
            Pin(num='N5',name='D19/SD_D19',func=pin_types.OUTPUT,unit=1),
            Pin(num='N6',name='BE/BWE0/SD_DQM0',func=pin_types.OUTPUT,unit=1),
            Pin(num='N7',name='D6/FB_D22',func=pin_types.OUTPUT,unit=1),
            Pin(num='N8',name='R/W',func=pin_types.OUTPUT,unit=1),
            Pin(num='N9',name='DDATA3',func=pin_types.OUTPUT,unit=1),
            Pin(num='P1',name='SD_SDR_DQS',func=pin_types.OUTPUT,unit=1),
            Pin(num='P10',name='DDATA0',func=pin_types.OUTPUT,unit=1),
            Pin(num='P11',name='QSPI_CSO/PWM5',func=pin_types.OUTPUT,unit=1),
            Pin(num='P12',name='QSPI_DOUT/I2C_SDA',func=pin_types.OUTPUT,unit=1),
            Pin(num='P13',name='EXTAL32K',func=pin_types.INPUT,unit=1),
            Pin(num='P14',name='/RSTOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='P15',name='DSCLK/TRST',func=pin_types.INPUT,unit=1),
            Pin(num='P16',name='EXTAL',func=pin_types.INPUT,unit=1),
            Pin(num='P2',name='SD_A10',func=pin_types.OUTPUT,unit=1),
            Pin(num='P3',name='/SD_SCAS',func=pin_types.OUTPUT,unit=1),
            Pin(num='P4',name='D22/SD_D22',func=pin_types.OUTPUT,unit=1),
            Pin(num='P5',name='D18/SD_D18',func=pin_types.OUTPUT,unit=1),
            Pin(num='P6',name='BE/BWE2/SD_DQM2',func=pin_types.OUTPUT,unit=1),
            Pin(num='P7',name='D5/FB_D21',func=pin_types.OUTPUT,unit=1),
            Pin(num='P8',name='D2/FB_D18',func=pin_types.OUTPUT,unit=1),
            Pin(num='P9',name='DDATA2',func=pin_types.OUTPUT,unit=1),
            Pin(num='R1',name='SD_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='R10',name='PST3',func=pin_types.OUTPUT,unit=1),
            Pin(num='R11',name='PST1',func=pin_types.OUTPUT,unit=1),
            Pin(num='R12',name='QSPI_CLK/I2C_SCL',func=pin_types.OUTPUT,unit=1),
            Pin(num='R13',name='XTAL32K',func=pin_types.OUTPUT,unit=1),
            Pin(num='R14',name='U0RXD',func=pin_types.INPUT,unit=1),
            Pin(num='R15',name='/U0CTS',func=pin_types.INPUT,unit=1),
            Pin(num='R16',name='BKPT/TMS',func=pin_types.INPUT,unit=1),
            Pin(num='R2',name='/SD_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='R3',name='/SD_SRAS',func=pin_types.OUTPUT,unit=1),
            Pin(num='R4',name='D21/SD_D21',func=pin_types.OUTPUT,unit=1),
            Pin(num='R5',name='D17/SD_D17',func=pin_types.OUTPUT,unit=1),
            Pin(num='R6',name='D7/FB_D23',func=pin_types.OUTPUT,unit=1),
            Pin(num='R7',name='D4/FB_D20',func=pin_types.OUTPUT,unit=1),
            Pin(num='R8',name='D1/FB_D17',func=pin_types.OUTPUT,unit=1),
            Pin(num='R9',name='OE',func=pin_types.OUTPUT,unit=1),
            Pin(num='T10',name='PST2',func=pin_types.OUTPUT,unit=1),
            Pin(num='T11',name='PST0',func=pin_types.OUTPUT,unit=1),
            Pin(num='T12',name='QSPI_CS2/U2RTS',func=pin_types.OUTPUT,unit=1),
            Pin(num='T13',name='QSPI_CS1/PWM7',func=pin_types.OUTPUT,unit=1),
            Pin(num='T14',name='U0TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='T15',name='/U0RTS',func=pin_types.OUTPUT,unit=1),
            Pin(num='T2',name='FB_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='T3',name='D23/SD_D23',func=pin_types.OUTPUT,unit=1),
            Pin(num='T4',name='D20/SD_D20',func=pin_types.OUTPUT,unit=1),
            Pin(num='T5',name='D16/SD_D16',func=pin_types.OUTPUT,unit=1),
            Pin(num='T6',name='SD_DQS2',func=pin_types.INPUT,unit=1),
            Pin(num='T7',name='D3/FB_D19',func=pin_types.OUTPUT,unit=1),
            Pin(num='T8',name='D0/FB_D16',func=pin_types.OUTPUT,unit=1),
            Pin(num='T9',name='PSTCLK/TCLK',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCF5407', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCF5407'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'COLDFIRE', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_ColdFire.kicad_sym\nMCF5407\n\nCOLDFIRE', 'pins':[
            Pin(num='1',name='IVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='/BE3',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='102',name='SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='105',name='IVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='106',name='D31',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='D30',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='D29',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='A6',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='D28',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='D27',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='D26',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='EVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='114',name='D25',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='D24',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='D23',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='118',name='D22',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='D21',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='A7',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='D20',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='EVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='D19',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='D18',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='D17',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='126',name='D16',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='D15',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='D14',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='EVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='EVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='130',name='D13',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='D12',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='D11',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='134',name='D10',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='D9',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='D8',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='EVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='138',name='D7',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='D6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='A8',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='D5',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='142',name='D4',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='D3',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='D2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='EVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='146',name='D1',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='D0',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='149',name='DSCLK',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A9',func=pin_types.BIDIR,unit=1),
            Pin(num='150',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='151',name='DSO',func=pin_types.OUTPUT,unit=1),
            Pin(num='152',name='IVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='153',name='DSI',func=pin_types.INPUT,unit=1),
            Pin(num='154',name='/BKPT',func=pin_types.INPUT,unit=1),
            Pin(num='155',name='/HIZ',func=pin_types.INPUT,unit=1),
            Pin(num='156',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='157',name='IVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='158',name='/CTS1',func=pin_types.INPUT,unit=1),
            Pin(num='159',name='/RTS1',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='A10',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='RXD1',func=pin_types.INPUT,unit=1),
            Pin(num='161',name='TXD1',func=pin_types.OUTPUT,unit=1),
            Pin(num='162',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='163',name='/CTS0',func=pin_types.INPUT,unit=1),
            Pin(num='164',name='/RTS0',func=pin_types.OUTPUT,unit=1),
            Pin(num='165',name='RXD0',func=pin_types.INPUT,unit=1),
            Pin(num='166',name='TXD0',func=pin_types.OUTPUT,unit=1),
            Pin(num='167',name='EVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='168',name='EDGESEL',func=pin_types.INPUT,unit=1),
            Pin(num='169',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='170',name='BCLKO',func=pin_types.OUTPUT,unit=1),
            Pin(num='171',name='IVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='172',name='/RSTO',func=pin_types.OUTPUT,unit=1),
            Pin(num='173',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='174',name='CLKIN',func=pin_types.OUTPUT,unit=1),
            Pin(num='175',name='IVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='176',name='MTMOD0',func=pin_types.INPUT,unit=1),
            Pin(num='177',name='MTMOD1',func=pin_types.INPUT,unit=1),
            Pin(num='178',name='PGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='A11',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='PVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='181',name='MTMOD2',func=pin_types.INPUT,unit=1),
            Pin(num='182',name='MTMOD3',func=pin_types.INPUT,unit=1),
            Pin(num='183',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='184',name='PSTCLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='185',name='IVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='186',name='PSTDDATA0',func=pin_types.OUTPUT,unit=1),
            Pin(num='187',name='PSTDDATA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='188',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='189',name='PSTDDATA2',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='A12',func=pin_types.BIDIR,unit=1),
            Pin(num='190',name='PSTDDATA3',func=pin_types.OUTPUT,unit=1),
            Pin(num='191',name='EVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='192',name='PSTDDATA4',func=pin_types.OUTPUT,unit=1),
            Pin(num='193',name='PSTDDATA5',func=pin_types.OUTPUT,unit=1),
            Pin(num='194',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='195',name='PSTDDATA6',func=pin_types.OUTPUT,unit=1),
            Pin(num='196',name='PSTDDATA7',func=pin_types.OUTPUT,unit=1),
            Pin(num='197',name='IVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='198',name='PP7/TIP',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='PP6/DREQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='A13',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='PP5/DREQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='202',name='PP4/TM2',func=pin_types.BIDIR,unit=1),
            Pin(num='203',name='PP3/TM1',func=pin_types.BIDIR,unit=1),
            Pin(num='204',name='PP2/TM0',func=pin_types.BIDIR,unit=1),
            Pin(num='205',name='EVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='206',name='PP1/TT1',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='PP0/TT0',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='EVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='A14',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='A15',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='A16',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='A17',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='A18',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='A19',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='EVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='A20',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='A21',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='A22',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='A23',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PP8/A24',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PP9/A25',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='EVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PP10/A26',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PP11/A27',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PP12/A28',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PP13/A29',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PP14/A30',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PP15/A31',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='EVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='SIZ0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='SIZ1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='/OE',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='A2',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='/CS0',func=pin_types.OUTPUT,unit=1),
            Pin(num='51',name='/CS1',func=pin_types.OUTPUT,unit=1),
            Pin(num='52',name='EVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='54',name='/CS2',func=pin_types.OUTPUT,unit=1),
            Pin(num='55',name='/CS3',func=pin_types.OUTPUT,unit=1),
            Pin(num='56',name='/CS4',func=pin_types.OUTPUT,unit=1),
            Pin(num='57',name='IVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='/CS5',func=pin_types.OUTPUT,unit=1),
            Pin(num='59',name='/CS6',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='A3',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='/CS7',func=pin_types.OUTPUT,unit=1),
            Pin(num='61',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='/AS',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='R/W',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='/TA',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='EVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='66',name='/TS',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='/RSTI',func=pin_types.INPUT,unit=1),
            Pin(num='68',name='/IRQ7',func=pin_types.INPUT,unit=1),
            Pin(num='69',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='EVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='/IRQ5',func=pin_types.INPUT,unit=1),
            Pin(num='71',name='/IRQ3',func=pin_types.INPUT,unit=1),
            Pin(num='72',name='/IRQ1',func=pin_types.INPUT,unit=1),
            Pin(num='73',name='IVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='/BR',func=pin_types.OUTPUT,unit=1),
            Pin(num='75',name='/BD',func=pin_types.OUTPUT,unit=1),
            Pin(num='76',name='/BG',func=pin_types.INPUT,unit=1),
            Pin(num='77',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='78',name='TOUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='79',name='TOUT0',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='A4',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='TIN0',func=pin_types.INPUT,unit=1),
            Pin(num='81',name='EVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='82',name='TIN1',func=pin_types.INPUT,unit=1),
            Pin(num='83',name='/RAS0',func=pin_types.OUTPUT,unit=1),
            Pin(num='84',name='/RAS1',func=pin_types.OUTPUT,unit=1),
            Pin(num='85',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='86',name='/CAS0',func=pin_types.OUTPUT,unit=1),
            Pin(num='87',name='/CAS1',func=pin_types.OUTPUT,unit=1),
            Pin(num='88',name='/CAS2',func=pin_types.OUTPUT,unit=1),
            Pin(num='89',name='EVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='A5',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='/CAS3',func=pin_types.OUTPUT,unit=1),
            Pin(num='91',name='/DRAMW',func=pin_types.OUTPUT,unit=1),
            Pin(num='92',name='/SRAS',func=pin_types.OUTPUT,unit=1),
            Pin(num='93',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='94',name='/SCAS',func=pin_types.OUTPUT,unit=1),
            Pin(num='95',name='SCKE',func=pin_types.OUTPUT,unit=1),
            Pin(num='96',name='/BE0',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='EVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='98',name='/BE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='/BE2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCF5211CAE66', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCF5211CAE66'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'MCU', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MCF5213EC.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_ColdFire.kicad_sym\nMCF5211CAE66\n\nMCU', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='QSPI_DIN/EZPD/CANRX/RXD1/PQS1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='QSPI_DOUT/EZPQ/CANTX/RXD0/PQS0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='QSPI_CLK/EZPCK/SCL/RTS1/PQS2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='QSPI_CS0/SDA/CTS1/PQS3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RCON/EZPCS',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='JTAG_EN',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='DTIN2/DTOUT2/PWM4/PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='DTIN3/DTOUT3/PWM6/PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='~{URTS1}/SYNCB/UTXD2/PUB2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='DTIN0/DTOUT0/PWM0/PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='DTIN1/DTOUT1/PWM2/PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='CLKMOD0',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='AN0/PAN0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='AN1/PAN1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AN2/PAN2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='AN3/PAN3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VSSA',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='VRL',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='VRH',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VCCA',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='AN7/PAN7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='AN6/PAN6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='AN5/PAN5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='AN4/PAN4',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VSTBY',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~{UCTS0}/CANRTX/PUA3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='GPT0/PWM1/PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='GPT1/PWM3/PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='GPT2PWM5//PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='GPT3/PWM7/PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='TCLK/PSTCLK/CLKOUT',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='GNDPLL',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='XTAL',func=pin_types.OUTPUT,unit=1),
            Pin(num='47',name='CLKIN/EXTAL',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='VCCPLL',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='~{BKPT}/TMS',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='URXD0/PUA1',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='DSI/TDI',func=pin_types.INPUT,unit=1),
            Pin(num='51',name='DSO/TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='54',name='DSCLK/~{TRST}',func=pin_types.INPUT,unit=1),
            Pin(num='55',name='ALLPST',func=pin_types.OUTPUT,unit=1),
            Pin(num='56',name='~{IRQ1}/PNQ1/SYNCA/PWM1',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='IRQ4*/PNQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='IRQ7*/PNQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='RSTI',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='UTXD0/PUA0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='RSTO',func=pin_types.OUTPUT,unit=1),
            Pin(num='61',name='~{UCTS1}/SYNCA/URXD2/PUB3',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='UTXD1/PUB0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='URXD1/PUB1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='~{URTS0}/CANTX/PUA2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SCL/PAS0/UTxD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SDA/PAS1/URxD2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] })])


# -*- coding: utf-8 -*-

# The MIT License (MIT) - Copyright (c) Dave Vandenbout.

"""
Base object for Circuit, Interface, Part, Net, Bus, Pin objects.

This module provides the foundation class SkidlBaseObject that all major SKiDL objects
inherit from. It implements common functionality such as ERC checking, attribute handling,
and object copying.
"""

import inspect
import random
import string
import os.path
from collections import namedtuple
from copy import deepcopy

from .alias import Alias
from .note import Note
from .utilities import export_to_all


__all__ = ["OK", "WARNING", "ERROR"]

OK, WARNING, ERROR = list(range(3))


@export_to_all
class SkidlBaseObject(object):
    """
    Base class for all SKiDL objects.

    This class provides common functionality for all SKiDL objects such as
    attribute handling, ERC checking, and object copying. It also manages
    object names, aliases, and notes.
    """

    # These are fallback lists so every object will have them to reference.
    erc_list = list()
    erc_assertion_list = list()

    def __init__(self):
        """Initialize a new SkidlBaseObject with empty fields dictionary."""
        self.fields = {}

    def __getattr__(self, key):
        """
        Retrieve an attribute from the fields dictionary.

        Args:
            key: The attribute name to retrieve.

        Returns:
            The value of the attribute.

        Raises:
            AttributeError: If the attribute doesn't exist.
        """
        try:
            # Don't use super()!! It leads to long run times on Python 2.7.
            return self.__getattribute__("fields")[key]
        except KeyError:
            raise AttributeError

    def __setattr__(self, key, value):
        """
        Set an attribute either directly or in the fields dictionary.

        If the key is 'fields' or doesn't exist in fields, sets it directly,
        otherwise updates the fields dictionary.

        Args:
            key: The attribute name to set.
            value: The value to assign to the attribute.
        """
        if key == "fields" or key not in self.fields:
            super().__setattr__(key, value)
        else:
            self.fields[key] = value

    def copy(self):
        """
        Create a deep copy of this object.

        Returns:
            A new SkidlBaseObject with copies of this object's fields, aliases, and notes.
        """
        cpy = SkidlBaseObject()
        cpy.fields = deepcopy(self.fields)
        try:
            cpy.aliases = deepcopy(self.aliases)
        except AttributeError:
            pass
        try:
            cpy.notes = deepcopy(self.notes)
        except AttributeError:
            pass
        return cpy

    def ERC(self, *args, **kwargs):
        """
        Run Electrical Rules Check on this object.

        This method runs all ERC functions and evaluates all ERC assertions
        assigned to the object.

        Args:
            *args: Arguments to pass to ERC functions.
            **kwargs: Keyword arguments to pass to ERC functions.
        """
        # Run ERC functions.
        self._exec_erc_functions(*args, **kwargs)

        # Run ERC assertions.
        self._eval_erc_assertions()

    def add_erc_function(self, func):
        """
        Add an ERC function to this object or its class.

        Args:
            func: A function that will be called during ERC checking.
        """
        self.erc_list.append(func)

    def add_erc_assertion(self, assertion, fail_msg="FAILED", severity=ERROR):
        """
        Add an ERC assertion to this object or its class.

        Args:
            assertion: A string containing a Python expression that should evaluate to True.
            fail_msg: Message to display if assertion fails.
            severity: Level of severity (ERROR, WARNING, or OK) if assertion fails.
        """
        # Tuple for storing assertion code object with its global & local dicts.
        EvalTuple = namedtuple(
            "EvalTuple",
            "stmnt fail_msg severity filename lineno function globals locals",
        )

        assertion_frame, filename, lineno, function, _, _ = inspect.stack()[1]
        self.erc_assertion_list.append(
            EvalTuple(
                assertion,
                fail_msg,
                severity,
                filename,
                lineno,
                function,
                assertion_frame.f_globals,
                assertion_frame.f_locals,
            )
        )

    def _eval_erc_assertions(self):
        """
        Evaluate all ERC assertions for this object.

        This method evaluates all assertions and logs failures with appropriate
        severity levels.
        """
        from .logger import active_logger

        def erc_report(evtpl):
            log_msg = f"{evtpl.stmnt} {evtpl.fail_msg} in {evtpl.filename}:{evtpl.lineno}:{evtpl.function}."
            if evtpl.severity == ERROR:
                active_logger.error(log_msg)
            elif evtpl.severity == WARNING:
                active_logger.warning(log_msg)

        for evtpl in self.erc_assertion_list:
            if eval(evtpl.stmnt, evtpl.globals, evtpl.locals) == False:
                erc_report(evtpl)

    def _exec_erc_functions(self, *args, **kwargs):
        """
        Execute ERC functions on this object.

        Args:
            *args: Arbitrary argument list passed to each ERC function.
            **kwargs: Arbitrary keyword arguments passed to each ERC function.
        """
        # Execute any instance functions for this particular instance.
        for f in self.erc_list:
            f(self, *args, **kwargs)

    @property
    def name(self):
        """
        Get the primary name of this object.

        Returns:
            The primary name of this object.
        """
        return self._name

    @name.setter
    def name(self, nm):
        """
        Set the primary name of this object and add it to aliases.

        Args:
            nm: The new name for this object.
        """
        del self.name  # Remove any pre-existing name.
        self.aliases += nm
        self._name = nm

    @name.deleter
    def name(self):
        """Remove the primary name from this object and its aliases."""
        try:
            self.aliases.discard(self._name)
            self._name = None
        except AttributeError:
            pass

    @property
    def tag(self):
        """
        Get the tag of this object.

        Returns:
            The tag of this object.
        """
        return self._tag

    @tag.setter
    def tag(self, tag_):
        """
        Set the tag of this object.

        Args:
            tag_: The new tag for this object.
        """
        del self.tag  # Remove any pre-existing tag.
        self._tag = tag_

    @tag.deleter
    def tag(self):
        """Remove the tag from this object."""
        try:
            del self._tag
        except AttributeError:
            pass

    def check_tag(self, create_if_missing=False):
        """
        Check if the tag is set for this object.
        Warn if the tag is not set.

        Returns:
            True if the tag is set, False otherwise.
        """
        from skidl.logger import active_logger

        if getattr(self, "tag", None):
            return True
        else:
            active_logger.bare_warning(
                f"Missing tag on {self.name} instantiated at {self.src_line(True)}."
            )
            if create_if_missing:
                # Create a random tag if it is missing.
                chars = string.ascii_letters + string.digits + "_"
                length = 10
                self.tag = ''.join(random.choices(chars, k=length))
                active_logger.bare_warning(
                    f"Random tag {self.tag} generated for {self.name}."
                )
            return False

    @property
    def aliases(self):
        """
        Get the aliases for this object.

        Returns:
            An Alias object containing all alternate names for this object.
        """
        try:
            return self._aliases
        except AttributeError:
            return Alias([])  # No aliases, so just return an empty list.

    @aliases.setter
    def aliases(self, name_or_list):
        """
        Set aliases for this object.

        Args:
            name_or_list: A name or list of names to use as aliases.
        """
        if not name_or_list:
            return
        self._aliases = Alias(name_or_list)

    @aliases.deleter
    def aliases(self):
        """Remove all aliases from this object."""
        try:
            del self._aliases
        except AttributeError:
            pass

    @property
    def notes(self):
        """
        Get the notes for this object.

        Returns:
            A Note object containing all notes associated with this object.
        """
        try:
            return self._notes
        except AttributeError:
            return Note([])  # No notes, so just return empty list.

    @notes.setter
    def notes(self, text_or_notes):
        """
        Set notes for this object.

        Args:
            text_or_notes: Text string or Note object to associate with this object.
        """
        if not text_or_notes:
            return
        self._notes = Note(text_or_notes)

    @notes.deleter
    def notes(self):
        """Remove all notes from this object."""
        try:
            del self._notes
        except AttributeError:
            pass

    def src_line(self, track_abs_path=False):
        """
        Return the file name and line number where the object was instantiated.

        Args:
            track_abs_path (bool): If True, use the absolute path of the file.
                                   If False, use the relative path from the script directory.
        
        Returns:
            str: File name and line number separated by colon.
        """
        try:
            file_path, file_line = self.skidl_trace[-1]
        except (AttributeError, IndexError):
            # If skidl_trace is not set or empty, return an empty string.
            return ""
        if not track_abs_path:
            file_path = os.path.relpath(file_path, self.circuit.script_dir)
        return file_path + ":" + file_line

